{
  description = "A nixvim configuration";

  inputs = {
    emacs-overlay.url = "github:nix-community/emacs-overlay";
    flake-utils.url = "github:numtide/flake-utils";
    nixpkgs.url = "github:NixOS/nixpkgs/nixos-unstable";
    treefmt-nix.url = "github:numtide/treefmt-nix";
  };

  outputs = {
    emacs-overlay,
    flake-utils,
    nixpkgs,
    treefmt-nix,
    ...
  }:
    flake-utils.lib.eachDefaultSystem (system: let
      pkgs = import nixpkgs {
        inherit system;
        config.allowUnfree = true;
        overlays = [emacs-overlay.overlay];
      };
    in {
      formatter = treefmt-nix.lib.mkWrapper pkgs {
        projectRootFile = "flake.nix";
        programs = {
          alejandra.enable = true;
          deadnix.enable = true;
          stylua.enable = true;
        };
      };

      packages.default = import ./config {inherit pkgs;};

      devShells.default = pkgs.mkShell {
        buildInputs = with pkgs; [
          alejandra
          nvfetcher
          stylua
          (writeScriptBin "up" ''
            nvfetcher
            nix flake update
          '')
        ];
      };
    });
}
